from setuptools import setup

setup(
    name='AmosLogger',
    version='0.0.3',
    author='ganyu',
    author_email='amosbow@163.com',
    url='https://github.com/bowofamos/amos_log#readme',
    long_description=open('README.md', 'r').read(),
    long_description_content_type='text/markdown',
    description='Amos Logger',
    packages=['AmosLogger'],
    install_requires=[]
)
